# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.response_wrapper_chat_message import ResponseWrapperChatMessage  # noqa: E501

class TestResponseWrapperChatMessage(unittest.TestCase):
    """ResponseWrapperChatMessage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperChatMessage:
        """Test ResponseWrapperChatMessage
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperChatMessage`
        """
        model = ResponseWrapperChatMessage()  # noqa: E501
        if include_optional:
            return ResponseWrapperChatMessage(
                done = True,
                result = chat_server_connector.models.chat_message.ChatMessage(
                    text = '', 
                    file_id = '', 
                    id = 56, 
                    chat_id = 56, 
                    chat_member_id = 56, 
                    chat_session_id = 56, 
                    is_hidden = True, 
                    inserted_by_member_id = 56, 
                    chat_message_type = null, 
                    added_at = 56, 
                    deleted_at = 56, ),
                error = ''
            )
        else:
            return ResponseWrapperChatMessage(
                done = True,
        )
        """

    def testResponseWrapperChatMessage(self):
        """Test ResponseWrapperChatMessage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
